@@ -2,8 +2,6 @@
 require( tcltk)
 require( ismev)
 extremes.gui()
-cat("\n",
-"Package extRemes: this is a beta version.  For information check out", "\n")
+cat("\n", "Package extRemes: For a tutorial and more information go to", "\n")
 cat("http://www.esig.ucar.edu/extremevalues/evtk.html", "\n")
-cat( "Or send email to ericg@(Remove this)ucar.edu", "\n")
 } # end of '.First.lib' fcn
